# nonebot_plugin_Imagelabels
@https://github.com/istrashguy/nonebot_plugin_Imagelabels

基于yolov5实现的图像标注插件



在插件被成功导入到nonebot后将自动检查yolov5-master是否位于Bot根目录，如果没有，将自动下载yolov5-master文件夹于根目录并安装相关依赖


（请注意：执行上述操作时Bot处于堵塞状态，将无法接收并处理其他消息！！这种状态可能持续10多分钟 安装完成后将自动生成parameter.json于根目录    可以自己将yolov5文件夹放置于Bot根目录，并安装相关依赖）

